==> ultra-erp-clean-v2.1.zip: src/Views/catalog/products/index.php <==
<h5>Mahsulotlar</h5>
<div class="mb-2 d-flex gap-2"><button class="btn btn-primary btn-sm" data-bs-toggle="modal" data-bs-target="#pNew"><i class="bi bi-plus"></i> Yangi</button></div>
<table class="table table-sm table-hover"><thead><tr><th>Kod</th><th>Nomi</th><th>Brend</th><th>Turkum</th><th>Birlik</th><th></th></tr></thead><tbody>
<?php foreach($rows as $r): ?><tr>
  <td><?=$r['code']?></td><td><img src="<?=$r['avatar_url']?:('https://api.dicebear.com/7.x/shapes/svg?seed='.urlencode($r['code']))?>" width="24" height="24" class="me-1"><?=$r['name']?></td>
  <td><?=$r['brand']?></td><td><?=$r['category']?></td><td><?=$r['uom']?></td>
  <td class="text-end">
    <button class="btn btn-outline-secondary btn-sm" data-bs-toggle="modal" data-bs-target="#pEdit"
      data-id="<?=$r['id']?>" data-code="<?=$r['code']?>" data-name="<?=$r['name']?>" data-uom="<?=$r['uom']?>" data-brand="<?=$r['brand']?>" data-category="<?=$r['category']?>" data-avatar="<?=$r['avatar_url']?>">Tahrirlash</button>
    <form method="post" action="?r=catalog/products/delete" onsubmit="return confirm('O‘chirish?')" class="d-inline"><input type="hidden" name="id" value="<?=$r['id']?>"><button class="btn btn-outline-danger btn-sm"><i class="bi bi-trash"></i></button></form>
  </td>
</tr><?php endforeach; ?></tbody></table>

<!-- New -->
<div class="modal fade" id="pNew" tabindex="-1"><div class="modal-dialog modal-lg"><div class="modal-content">
<div class="modal-header py-2"><h6>Yangi mahsulot</h6><button class="btn-close" data-bs-dismiss="modal"></button></div>
<form method="post" action="?r=catalog/products/create"><div class="modal-body"><div class="row g-2">
  <div class="col-md-4"><label class="form-label">Kod</label><input class="form-control form-control-sm" name="code" required></div>
  <div class="col-md-8"><label class="form-label">Nomi</label><input class="form-control form-control-sm" name="name" required></div>
  <div class="col-md-3"><label class="form-label">Birlik</label><input class="form-control form-control-sm" name="uom" value="dona"></div>
  <div class="col-md-3"><label class="form-label">Brend</label><input class="form-control form-control-sm" name="brand"></div>
  <div class="col-md-3"><label class="form-label">Turkum</label><input class="form-control form-control-sm" name="category"></div>
  <div class="col-md-3"><label class="form-label">Rasm (URL)</label><input class="form-control form-control-sm" name="avatar_url" placeholder="https://..."></div>
</div></div><div class="modal-footer py-2"><button class="btn btn-secondary" data-bs-dismiss="modal">Yopish</button><button class="btn btn-primary">Saqlash</button></div></form>
</div></div></div>

<!-- Edit -->
<div class="modal fade" id="pEdit" tabindex="-1"><div class="modal-dialog modal-lg"><div class="modal-content">
<div class="modal-header py-2"><h6>Tahrirlash</h6><button class="btn-close" data-bs-dismiss="modal"></button></div>
<form method="post" action="?r=catalog/products/update"><div class="modal-body"><input type="hidden" name="id" id="pe_id">
<div class="row g-2">
  <div class="col-md-4"><label class="form-label">Kod</label><input class="form-control form-control-sm" id="pe_code" name="code" required></div>
  <div class="col-md-8"><label class="form-label">Nomi</label><input class="form-control form-control-sm" id="pe_name" name="name" required></div>
  <div class="col-md-3"><label class="form-label">Birlik</label><input class="form-control form-control-sm" id="pe_uom" name="uom"></div>
  <div class="col-md-3"><label class="form-label">Brend</label><input class="form-control form-control-sm" id="pe_brand" name="brand"></div>
  <div class="col-md-3"><label class="form-label">Turkum</label><input class="form-control form-control-sm" id="pe_category" name="category"></div>
  <div class="col-md-3"><label class="form-label">Rasm (URL)</label><input class="form-control form-control-sm" id="pe_avatar" name="avatar_url"></div>
</div></div><div class="modal-footer py-2"><button class="btn btn-secondary" data-bs-dismiss="modal">Yopish</button><button class="btn btn-primary">Saqlash</button></div></form>
</div></div></div>
<script>
document.getElementById('pEdit').addEventListener('show.bs.modal', function (ev){
  const b=ev.relatedTarget; pe_id.value=b.dataset.id; pe_code.value=b.dataset.code; pe_name.value=b.dataset.name;
  pe_uom.value=b.dataset.uom; pe_brand.value=b.dataset.brand; pe_category.value=b.dataset.category; pe_avatar.value=b.dataset.avatar;
});
</script>

==> ultra-erp-clean-v2.2.zip: src/Views/catalog/products/index.php <==
<h5>Mahsulotlar</h5>
<button class="btn btn-primary btn-sm mb-2" data-bs-toggle="modal" data-bs-target="#pNew"><i class="bi bi-plus"></i> Yangi</button>
<table class="table table-sm table-hover"><thead><tr><th>Kod</th><th>Nomi</th><th>Brend</th><th>Turkum</th><th>Birlik</th><th></th></tr></thead><tbody>
<?php foreach($rows as $r): ?><tr>
  <td><?=$r['code']?></td><td><img src="<?=$r['avatar_url']?:('https://api.dicebear.com/7.x/shapes/svg?seed='.urlencode($r['code']))?>" width="24" height="24" class="me-1"><?=$r['name']?></td>
  <td><?=$r['brand']?></td><td><?=$r['category']?></td><td><?=$r['uom']?></td>
  <td class="text-end"><form method="post" action="<?= \App\Core\Response::url(\'\1\') ?>" onsubmit="return confirm('O‘chirish?')" class="d-inline"><input type="hidden" name="id" value="<?=$r['id']?>"><button class="btn btn-outline-danger btn-sm"><i class="bi bi-trash"></i></button></form></td>
</tr><?php endforeach; ?></tbody></table>
<div class="modal fade" id="pNew" tabindex="-1"><div class="modal-dialog modal-lg"><div class="modal-content">
<div class="modal-header py-2"><h6>Yangi mahsulot</h6><button class="btn-close" data-bs-dismiss="modal"></button></div>
<form method="post" action="<?= \App\Core\Response::url(\'\1\') ?>"><div class="modal-body"><div class="row g-2">
  <div class="col-md-4"><label class="form-label">Kod</label><input class="form-control form-control-sm" name="code" required></div>
  <div class="col-md-8"><label class="form-label">Nomi</label><input class="form-control form-control-sm" name="name" required></div>
  <div class="col-md-3"><label class="form-label">Birlik</label><input class="form-control form-control-sm" name="uom" value="dona"></div>
  <div class="col-md-3"><label class="form-label">Brend</label><input class="form-control form-control-sm" name="brand"></div>
  <div class="col-md-3"><label class="form-label">Turkum</label><input class="form-control form-control-sm" name="category"></div>
  <div class="col-md-3"><label class="form-label">Rasm (URL)</label><input class="form-control form-control-sm" name="avatar_url" placeholder="https://..."></div>
</div></div><div class="modal-footer py-2"><button class="btn btn-secondary" data-bs-dismiss="modal">Yopish</button><button class="btn btn-primary">Saqlash</button></div></form>
</div></div></div>
